
# THIS FILE IS GENERATED FROM tyssue SETUP.PY
#
short_version = '0.4.rc1'
version = '0.4.rc1'
full_version = '0.4.rc1'
git_revision = 'Unknown'
release = True
if not release:
    version = full_version
